/*=========================================================================*//**
@file    gpio_cfg.h

@author  Daniel Zorychta

@brief   This driver support GPIO. Set here driver configuration.

@note    Copyright (C) 2012  Daniel Zorychta <daniel.zorychta@gmail.com>

         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
         the Free Software Foundation and modified by the dnx RTOS exception.

         NOTE: The modification  to the GPL is  included to allow you to
               distribute a combined work that includes dnx RTOS without
               being obliged to provide the source  code for proprietary
               components outside of the dnx RTOS.

         The dnx RTOS  is  distributed  in the hope  that  it will be useful,
         but WITHOUT  ANY  WARRANTY;  without  even  the implied  warranty of
         MERCHANTABILITY  or  FITNESS  FOR  A  PARTICULAR  PURPOSE.  See  the
         GNU General Public License for more details.

         Full license text is available on the following file: doc/license.txt.


*//*==========================================================================*/

#ifndef _GPIO_CFG_H_
#define _GPIO_CFG_H_

#ifdef __cplusplus
extern "C" {
#endif

/*==============================================================================
  Include files
==============================================================================*/
#include "efr32/efr32xx.h"
#include "efr32/gpio_macros.h"

/*==============================================================================
  Exported symbolic constants/macros
==============================================================================*/
/** macro creates an enumerator with pin data */
#define _PIN_CONFIGURATION(port, port_idx, number, pin_name, mode, state) \
enum port##_##number##_CFG {\
        _CONCAT(IOCTL_GPIO_PIN_IDX__, pin_name) = number,\
        _CONCAT(IOCTL_GPIO_PIN_MASK__, pin_name) = (1 << (number)),\
        _CONCAT(IOCTL_GPIO_PORT_IDX__, pin_name) = port_idx,\
        _CONCAT(_BP_, pin_name) = (number),\
        _CONCAT(_BM_, pin_name) = (1 << (number)),\
        _##port##_PIN_##number##_MODE  = (mode) & 0xF,\
        _##port##_PIN_##number##_STATE = (state) & 1,\
}

/** GPIO pin NONE definition */
_PIN_CONFIGURATION(_GPIO_NONE, 16, 17, NONE, _GPIO_MODE_DISABLED, _LOW);

/** GPIOA pins configuration */
#define _GPIOA_DRIVE_STRENGTH           __GPIO_PA_DRIVE_STRENGTH__
#define _GPIOA_DRIVE_STRENGTH_ALT       __GPIO_PA_DRIVE_STRENGTH_ALT__
#define _GPIOA_SLEW_RATE                __GPIO_PA_SLEW_RATE__
#define _GPIOA_SLEW_RATE_ALT            __GPIO_PA_SLEW_RATE_ALT__
#define _GPIOA_INPUT_DISABLE            __GPIO_PA_INPUT_DISABLE__
#define _GPIOA_INPUT_DISABLE_ALT        __GPIO_PA_INPUT_DISABLE_ALT__

_PIN_CONFIGURATION(GPIOA, 0,  0, __GPIO_PA_PIN_0_NAME__ , __GPIO_PA_PIN_0_MODE__ , __GPIO_PA_PIN_0_STATE__ );
_PIN_CONFIGURATION(GPIOA, 0,  1, __GPIO_PA_PIN_1_NAME__ , __GPIO_PA_PIN_1_MODE__ , __GPIO_PA_PIN_1_STATE__ );
_PIN_CONFIGURATION(GPIOA, 0,  2, __GPIO_PA_PIN_2_NAME__ , __GPIO_PA_PIN_2_MODE__ , __GPIO_PA_PIN_2_STATE__ );
_PIN_CONFIGURATION(GPIOA, 0,  3, __GPIO_PA_PIN_3_NAME__ , __GPIO_PA_PIN_3_MODE__ , __GPIO_PA_PIN_3_STATE__ );
_PIN_CONFIGURATION(GPIOA, 0,  4, __GPIO_PA_PIN_4_NAME__ , __GPIO_PA_PIN_4_MODE__ , __GPIO_PA_PIN_4_STATE__ );
_PIN_CONFIGURATION(GPIOA, 0,  5, __GPIO_PA_PIN_5_NAME__ , __GPIO_PA_PIN_5_MODE__ , __GPIO_PA_PIN_5_STATE__ );
_PIN_CONFIGURATION(GPIOA, 0,  6, __GPIO_PA_PIN_6_NAME__ , __GPIO_PA_PIN_6_MODE__ , __GPIO_PA_PIN_6_STATE__ );
_PIN_CONFIGURATION(GPIOA, 0,  7, __GPIO_PA_PIN_7_NAME__ , __GPIO_PA_PIN_7_MODE__ , __GPIO_PA_PIN_7_STATE__ );
_PIN_CONFIGURATION(GPIOA, 0,  8, __GPIO_PA_PIN_8_NAME__ , __GPIO_PA_PIN_8_MODE__ , __GPIO_PA_PIN_8_STATE__ );
_PIN_CONFIGURATION(GPIOA, 0,  9, __GPIO_PA_PIN_9_NAME__ , __GPIO_PA_PIN_9_MODE__ , __GPIO_PA_PIN_9_STATE__ );
_PIN_CONFIGURATION(GPIOA, 0, 10, __GPIO_PA_PIN_10_NAME__, __GPIO_PA_PIN_10_MODE__, __GPIO_PA_PIN_10_STATE__);
_PIN_CONFIGURATION(GPIOA, 0, 11, __GPIO_PA_PIN_11_NAME__, __GPIO_PA_PIN_11_MODE__, __GPIO_PA_PIN_11_STATE__);
_PIN_CONFIGURATION(GPIOA, 0, 12, __GPIO_PA_PIN_12_NAME__, __GPIO_PA_PIN_12_MODE__, __GPIO_PA_PIN_12_STATE__);
_PIN_CONFIGURATION(GPIOA, 0, 13, __GPIO_PA_PIN_13_NAME__, __GPIO_PA_PIN_13_MODE__, __GPIO_PA_PIN_13_STATE__);
_PIN_CONFIGURATION(GPIOA, 0, 14, __GPIO_PA_PIN_14_NAME__, __GPIO_PA_PIN_14_MODE__, __GPIO_PA_PIN_14_STATE__);
_PIN_CONFIGURATION(GPIOA, 0, 15, __GPIO_PA_PIN_15_NAME__, __GPIO_PA_PIN_15_MODE__, __GPIO_PA_PIN_15_STATE__);

/** GPIOB pins configuration */
#define _GPIOB_DRIVE_STRENGTH           __GPIO_PB_DRIVE_STRENGTH__
#define _GPIOB_DRIVE_STRENGTH_ALT       __GPIO_PB_DRIVE_STRENGTH_ALT__
#define _GPIOB_SLEW_RATE                __GPIO_PB_SLEW_RATE__
#define _GPIOB_SLEW_RATE_ALT            __GPIO_PB_SLEW_RATE_ALT__
#define _GPIOB_INPUT_DISABLE            __GPIO_PB_INPUT_DISABLE__
#define _GPIOB_INPUT_DISABLE_ALT        __GPIO_PB_INPUT_DISABLE_ALT__

_PIN_CONFIGURATION(GPIOB, 1,  0, __GPIO_PB_PIN_0_NAME__ , __GPIO_PB_PIN_0_MODE__ , __GPIO_PB_PIN_0_STATE__ );
_PIN_CONFIGURATION(GPIOB, 1,  1, __GPIO_PB_PIN_1_NAME__ , __GPIO_PB_PIN_1_MODE__ , __GPIO_PB_PIN_1_STATE__ );
_PIN_CONFIGURATION(GPIOB, 1,  2, __GPIO_PB_PIN_2_NAME__ , __GPIO_PB_PIN_2_MODE__ , __GPIO_PB_PIN_2_STATE__ );
_PIN_CONFIGURATION(GPIOB, 1,  3, __GPIO_PB_PIN_3_NAME__ , __GPIO_PB_PIN_3_MODE__ , __GPIO_PB_PIN_3_STATE__ );
_PIN_CONFIGURATION(GPIOB, 1,  4, __GPIO_PB_PIN_4_NAME__ , __GPIO_PB_PIN_4_MODE__ , __GPIO_PB_PIN_4_STATE__ );
_PIN_CONFIGURATION(GPIOB, 1,  5, __GPIO_PB_PIN_5_NAME__ , __GPIO_PB_PIN_5_MODE__ , __GPIO_PB_PIN_5_STATE__ );
_PIN_CONFIGURATION(GPIOB, 1,  6, __GPIO_PB_PIN_6_NAME__ , __GPIO_PB_PIN_6_MODE__ , __GPIO_PB_PIN_6_STATE__ );
_PIN_CONFIGURATION(GPIOB, 1,  7, __GPIO_PB_PIN_7_NAME__ , __GPIO_PB_PIN_7_MODE__ , __GPIO_PB_PIN_7_STATE__ );
_PIN_CONFIGURATION(GPIOB, 1,  8, __GPIO_PB_PIN_8_NAME__ , __GPIO_PB_PIN_8_MODE__ , __GPIO_PB_PIN_8_STATE__ );
_PIN_CONFIGURATION(GPIOB, 1,  9, __GPIO_PB_PIN_9_NAME__ , __GPIO_PB_PIN_9_MODE__ , __GPIO_PB_PIN_9_STATE__ );
_PIN_CONFIGURATION(GPIOB, 1, 10, __GPIO_PB_PIN_10_NAME__, __GPIO_PB_PIN_10_MODE__, __GPIO_PB_PIN_10_STATE__);
_PIN_CONFIGURATION(GPIOB, 1, 11, __GPIO_PB_PIN_11_NAME__, __GPIO_PB_PIN_11_MODE__, __GPIO_PB_PIN_11_STATE__);
_PIN_CONFIGURATION(GPIOB, 1, 12, __GPIO_PB_PIN_12_NAME__, __GPIO_PB_PIN_12_MODE__, __GPIO_PB_PIN_12_STATE__);
_PIN_CONFIGURATION(GPIOB, 1, 13, __GPIO_PB_PIN_13_NAME__, __GPIO_PB_PIN_13_MODE__, __GPIO_PB_PIN_13_STATE__);
_PIN_CONFIGURATION(GPIOB, 1, 14, __GPIO_PB_PIN_14_NAME__, __GPIO_PB_PIN_14_MODE__, __GPIO_PB_PIN_14_STATE__);
_PIN_CONFIGURATION(GPIOB, 1, 15, __GPIO_PB_PIN_15_NAME__, __GPIO_PB_PIN_15_MODE__, __GPIO_PB_PIN_15_STATE__);

/** GPIOC pins configuration */
#define _GPIOC_DRIVE_STRENGTH           __GPIO_PC_DRIVE_STRENGTH__
#define _GPIOC_DRIVE_STRENGTH_ALT       __GPIO_PC_DRIVE_STRENGTH_ALT__
#define _GPIOC_SLEW_RATE                __GPIO_PC_SLEW_RATE__
#define _GPIOC_SLEW_RATE_ALT            __GPIO_PC_SLEW_RATE_ALT__
#define _GPIOC_INPUT_DISABLE            __GPIO_PC_INPUT_DISABLE__
#define _GPIOC_INPUT_DISABLE_ALT        __GPIO_PC_INPUT_DISABLE_ALT__

_PIN_CONFIGURATION(GPIOC, 2,  0, __GPIO_PC_PIN_0_NAME__ , __GPIO_PC_PIN_0_MODE__ , __GPIO_PC_PIN_0_STATE__ );
_PIN_CONFIGURATION(GPIOC, 2,  1, __GPIO_PC_PIN_1_NAME__ , __GPIO_PC_PIN_1_MODE__ , __GPIO_PC_PIN_1_STATE__ );
_PIN_CONFIGURATION(GPIOC, 2,  2, __GPIO_PC_PIN_2_NAME__ , __GPIO_PC_PIN_2_MODE__ , __GPIO_PC_PIN_2_STATE__ );
_PIN_CONFIGURATION(GPIOC, 2,  3, __GPIO_PC_PIN_3_NAME__ , __GPIO_PC_PIN_3_MODE__ , __GPIO_PC_PIN_3_STATE__ );
_PIN_CONFIGURATION(GPIOC, 2,  4, __GPIO_PC_PIN_4_NAME__ , __GPIO_PC_PIN_4_MODE__ , __GPIO_PC_PIN_4_STATE__ );
_PIN_CONFIGURATION(GPIOC, 2,  5, __GPIO_PC_PIN_5_NAME__ , __GPIO_PC_PIN_5_MODE__ , __GPIO_PC_PIN_5_STATE__ );
_PIN_CONFIGURATION(GPIOC, 2,  6, __GPIO_PC_PIN_6_NAME__ , __GPIO_PC_PIN_6_MODE__ , __GPIO_PC_PIN_6_STATE__ );
_PIN_CONFIGURATION(GPIOC, 2,  7, __GPIO_PC_PIN_7_NAME__ , __GPIO_PC_PIN_7_MODE__ , __GPIO_PC_PIN_7_STATE__ );
_PIN_CONFIGURATION(GPIOC, 2,  8, __GPIO_PC_PIN_8_NAME__ , __GPIO_PC_PIN_8_MODE__ , __GPIO_PC_PIN_8_STATE__ );
_PIN_CONFIGURATION(GPIOC, 2,  9, __GPIO_PC_PIN_9_NAME__ , __GPIO_PC_PIN_9_MODE__ , __GPIO_PC_PIN_9_STATE__ );
_PIN_CONFIGURATION(GPIOC, 2, 10, __GPIO_PC_PIN_10_NAME__, __GPIO_PC_PIN_10_MODE__, __GPIO_PC_PIN_10_STATE__);
_PIN_CONFIGURATION(GPIOC, 2, 11, __GPIO_PC_PIN_11_NAME__, __GPIO_PC_PIN_11_MODE__, __GPIO_PC_PIN_11_STATE__);
_PIN_CONFIGURATION(GPIOC, 2, 12, __GPIO_PC_PIN_12_NAME__, __GPIO_PC_PIN_12_MODE__, __GPIO_PC_PIN_12_STATE__);
_PIN_CONFIGURATION(GPIOC, 2, 13, __GPIO_PC_PIN_13_NAME__, __GPIO_PC_PIN_13_MODE__, __GPIO_PC_PIN_13_STATE__);
_PIN_CONFIGURATION(GPIOC, 2, 14, __GPIO_PC_PIN_14_NAME__, __GPIO_PC_PIN_14_MODE__, __GPIO_PC_PIN_14_STATE__);
_PIN_CONFIGURATION(GPIOC, 2, 15, __GPIO_PC_PIN_15_NAME__, __GPIO_PC_PIN_15_MODE__, __GPIO_PC_PIN_15_STATE__);

/** GPIOD pins configuration */
#define _GPIOD_DRIVE_STRENGTH           __GPIO_PD_DRIVE_STRENGTH__
#define _GPIOD_DRIVE_STRENGTH_ALT       __GPIO_PD_DRIVE_STRENGTH_ALT__
#define _GPIOD_SLEW_RATE                __GPIO_PD_SLEW_RATE__
#define _GPIOD_SLEW_RATE_ALT            __GPIO_PD_SLEW_RATE_ALT__
#define _GPIOD_INPUT_DISABLE            __GPIO_PD_INPUT_DISABLE__
#define _GPIOD_INPUT_DISABLE_ALT        __GPIO_PD_INPUT_DISABLE_ALT__

_PIN_CONFIGURATION(GPIOD, 3,  0, __GPIO_PD_PIN_0_NAME__ , __GPIO_PD_PIN_0_MODE__ , __GPIO_PD_PIN_0_STATE__ );
_PIN_CONFIGURATION(GPIOD, 3,  1, __GPIO_PD_PIN_1_NAME__ , __GPIO_PD_PIN_1_MODE__ , __GPIO_PD_PIN_1_STATE__ );
_PIN_CONFIGURATION(GPIOD, 3,  2, __GPIO_PD_PIN_2_NAME__ , __GPIO_PD_PIN_2_MODE__ , __GPIO_PD_PIN_2_STATE__ );
_PIN_CONFIGURATION(GPIOD, 3,  3, __GPIO_PD_PIN_3_NAME__ , __GPIO_PD_PIN_3_MODE__ , __GPIO_PD_PIN_3_STATE__ );
_PIN_CONFIGURATION(GPIOD, 3,  4, __GPIO_PD_PIN_4_NAME__ , __GPIO_PD_PIN_4_MODE__ , __GPIO_PD_PIN_4_STATE__ );
_PIN_CONFIGURATION(GPIOD, 3,  5, __GPIO_PD_PIN_5_NAME__ , __GPIO_PD_PIN_5_MODE__ , __GPIO_PD_PIN_5_STATE__ );
_PIN_CONFIGURATION(GPIOD, 3,  6, __GPIO_PD_PIN_6_NAME__ , __GPIO_PD_PIN_6_MODE__ , __GPIO_PD_PIN_6_STATE__ );
_PIN_CONFIGURATION(GPIOD, 3,  7, __GPIO_PD_PIN_7_NAME__ , __GPIO_PD_PIN_7_MODE__ , __GPIO_PD_PIN_7_STATE__ );
_PIN_CONFIGURATION(GPIOD, 3,  8, __GPIO_PD_PIN_8_NAME__ , __GPIO_PD_PIN_8_MODE__ , __GPIO_PD_PIN_8_STATE__ );
_PIN_CONFIGURATION(GPIOD, 3,  9, __GPIO_PD_PIN_9_NAME__ , __GPIO_PD_PIN_9_MODE__ , __GPIO_PD_PIN_9_STATE__ );
_PIN_CONFIGURATION(GPIOD, 3, 10, __GPIO_PD_PIN_10_NAME__, __GPIO_PD_PIN_10_MODE__, __GPIO_PD_PIN_10_STATE__);
_PIN_CONFIGURATION(GPIOD, 3, 11, __GPIO_PD_PIN_11_NAME__, __GPIO_PD_PIN_11_MODE__, __GPIO_PD_PIN_11_STATE__);
_PIN_CONFIGURATION(GPIOD, 3, 12, __GPIO_PD_PIN_12_NAME__, __GPIO_PD_PIN_12_MODE__, __GPIO_PD_PIN_12_STATE__);
_PIN_CONFIGURATION(GPIOD, 3, 13, __GPIO_PD_PIN_13_NAME__, __GPIO_PD_PIN_13_MODE__, __GPIO_PD_PIN_13_STATE__);
_PIN_CONFIGURATION(GPIOD, 3, 14, __GPIO_PD_PIN_14_NAME__, __GPIO_PD_PIN_14_MODE__, __GPIO_PD_PIN_14_STATE__);
_PIN_CONFIGURATION(GPIOD, 3, 15, __GPIO_PD_PIN_15_NAME__, __GPIO_PD_PIN_15_MODE__, __GPIO_PD_PIN_15_STATE__);

/** GPIOE pins configuration */
#define _GPIOE_DRIVE_STRENGTH           __GPIO_PE_DRIVE_STRENGTH__
#define _GPIOE_DRIVE_STRENGTH_ALT       __GPIO_PE_DRIVE_STRENGTH_ALT__
#define _GPIOE_SLEW_RATE                __GPIO_PE_SLEW_RATE__
#define _GPIOE_SLEW_RATE_ALT            __GPIO_PE_SLEW_RATE_ALT__
#define _GPIOE_INPUT_DISABLE            __GPIO_PE_INPUT_DISABLE__
#define _GPIOE_INPUT_DISABLE_ALT        __GPIO_PE_INPUT_DISABLE_ALT__

_PIN_CONFIGURATION(GPIOE, 4,  0, __GPIO_PE_PIN_0_NAME__ , __GPIO_PE_PIN_0_MODE__ , __GPIO_PE_PIN_0_STATE__ );
_PIN_CONFIGURATION(GPIOE, 4,  1, __GPIO_PE_PIN_1_NAME__ , __GPIO_PE_PIN_1_MODE__ , __GPIO_PE_PIN_1_STATE__ );
_PIN_CONFIGURATION(GPIOE, 4,  2, __GPIO_PE_PIN_2_NAME__ , __GPIO_PE_PIN_2_MODE__ , __GPIO_PE_PIN_2_STATE__ );
_PIN_CONFIGURATION(GPIOE, 4,  3, __GPIO_PE_PIN_3_NAME__ , __GPIO_PE_PIN_3_MODE__ , __GPIO_PE_PIN_3_STATE__ );
_PIN_CONFIGURATION(GPIOE, 4,  4, __GPIO_PE_PIN_4_NAME__ , __GPIO_PE_PIN_4_MODE__ , __GPIO_PE_PIN_4_STATE__ );
_PIN_CONFIGURATION(GPIOE, 4,  5, __GPIO_PE_PIN_5_NAME__ , __GPIO_PE_PIN_5_MODE__ , __GPIO_PE_PIN_5_STATE__ );
_PIN_CONFIGURATION(GPIOE, 4,  6, __GPIO_PE_PIN_6_NAME__ , __GPIO_PE_PIN_6_MODE__ , __GPIO_PE_PIN_6_STATE__ );
_PIN_CONFIGURATION(GPIOE, 4,  7, __GPIO_PE_PIN_7_NAME__ , __GPIO_PE_PIN_7_MODE__ , __GPIO_PE_PIN_7_STATE__ );
_PIN_CONFIGURATION(GPIOE, 4,  8, __GPIO_PE_PIN_8_NAME__ , __GPIO_PE_PIN_8_MODE__ , __GPIO_PE_PIN_8_STATE__ );
_PIN_CONFIGURATION(GPIOE, 4,  9, __GPIO_PE_PIN_9_NAME__ , __GPIO_PE_PIN_9_MODE__ , __GPIO_PE_PIN_9_STATE__ );
_PIN_CONFIGURATION(GPIOE, 4, 10, __GPIO_PE_PIN_10_NAME__, __GPIO_PE_PIN_10_MODE__, __GPIO_PE_PIN_10_STATE__);
_PIN_CONFIGURATION(GPIOE, 4, 11, __GPIO_PE_PIN_11_NAME__, __GPIO_PE_PIN_11_MODE__, __GPIO_PE_PIN_11_STATE__);
_PIN_CONFIGURATION(GPIOE, 4, 12, __GPIO_PE_PIN_12_NAME__, __GPIO_PE_PIN_12_MODE__, __GPIO_PE_PIN_12_STATE__);
_PIN_CONFIGURATION(GPIOE, 4, 13, __GPIO_PE_PIN_13_NAME__, __GPIO_PE_PIN_13_MODE__, __GPIO_PE_PIN_13_STATE__);
_PIN_CONFIGURATION(GPIOE, 4, 14, __GPIO_PE_PIN_14_NAME__, __GPIO_PE_PIN_14_MODE__, __GPIO_PE_PIN_14_STATE__);
_PIN_CONFIGURATION(GPIOE, 4, 15, __GPIO_PE_PIN_15_NAME__, __GPIO_PE_PIN_15_MODE__, __GPIO_PE_PIN_15_STATE__);

/** GPIOF pins configuration */
#define _GPIOF_DRIVE_STRENGTH           __GPIO_PF_DRIVE_STRENGTH__
#define _GPIOF_DRIVE_STRENGTH_ALT       __GPIO_PF_DRIVE_STRENGTH_ALT__
#define _GPIOF_SLEW_RATE                __GPIO_PF_SLEW_RATE__
#define _GPIOF_SLEW_RATE_ALT            __GPIO_PF_SLEW_RATE_ALT__
#define _GPIOF_INPUT_DISABLE            __GPIO_PF_INPUT_DISABLE__
#define _GPIOF_INPUT_DISABLE_ALT        __GPIO_PF_INPUT_DISABLE_ALT__

_PIN_CONFIGURATION(GPIOF, 5,  0, __GPIO_PF_PIN_0_NAME__ , __GPIO_PF_PIN_0_MODE__ , __GPIO_PF_PIN_0_STATE__ );
_PIN_CONFIGURATION(GPIOF, 5,  1, __GPIO_PF_PIN_1_NAME__ , __GPIO_PF_PIN_1_MODE__ , __GPIO_PF_PIN_1_STATE__ );
_PIN_CONFIGURATION(GPIOF, 5,  2, __GPIO_PF_PIN_2_NAME__ , __GPIO_PF_PIN_2_MODE__ , __GPIO_PF_PIN_2_STATE__ );
_PIN_CONFIGURATION(GPIOF, 5,  3, __GPIO_PF_PIN_3_NAME__ , __GPIO_PF_PIN_3_MODE__ , __GPIO_PF_PIN_3_STATE__ );
_PIN_CONFIGURATION(GPIOF, 5,  4, __GPIO_PF_PIN_4_NAME__ , __GPIO_PF_PIN_4_MODE__ , __GPIO_PF_PIN_4_STATE__ );
_PIN_CONFIGURATION(GPIOF, 5,  5, __GPIO_PF_PIN_5_NAME__ , __GPIO_PF_PIN_5_MODE__ , __GPIO_PF_PIN_5_STATE__ );
_PIN_CONFIGURATION(GPIOF, 5,  6, __GPIO_PF_PIN_6_NAME__ , __GPIO_PF_PIN_6_MODE__ , __GPIO_PF_PIN_6_STATE__ );
_PIN_CONFIGURATION(GPIOF, 5,  7, __GPIO_PF_PIN_7_NAME__ , __GPIO_PF_PIN_7_MODE__ , __GPIO_PF_PIN_7_STATE__ );
_PIN_CONFIGURATION(GPIOF, 5,  8, __GPIO_PF_PIN_8_NAME__ , __GPIO_PF_PIN_8_MODE__ , __GPIO_PF_PIN_8_STATE__ );
_PIN_CONFIGURATION(GPIOF, 5,  9, __GPIO_PF_PIN_9_NAME__ , __GPIO_PF_PIN_9_MODE__ , __GPIO_PF_PIN_9_STATE__ );
_PIN_CONFIGURATION(GPIOF, 5, 10, __GPIO_PF_PIN_10_NAME__, __GPIO_PF_PIN_10_MODE__, __GPIO_PF_PIN_10_STATE__);
_PIN_CONFIGURATION(GPIOF, 5, 11, __GPIO_PF_PIN_11_NAME__, __GPIO_PF_PIN_11_MODE__, __GPIO_PF_PIN_11_STATE__);
_PIN_CONFIGURATION(GPIOF, 5, 12, __GPIO_PF_PIN_12_NAME__, __GPIO_PF_PIN_12_MODE__, __GPIO_PF_PIN_12_STATE__);
_PIN_CONFIGURATION(GPIOF, 5, 13, __GPIO_PF_PIN_13_NAME__, __GPIO_PF_PIN_13_MODE__, __GPIO_PF_PIN_13_STATE__);
_PIN_CONFIGURATION(GPIOF, 5, 14, __GPIO_PF_PIN_14_NAME__, __GPIO_PF_PIN_14_MODE__, __GPIO_PF_PIN_14_STATE__);
_PIN_CONFIGURATION(GPIOF, 5, 15, __GPIO_PF_PIN_15_NAME__, __GPIO_PF_PIN_15_MODE__, __GPIO_PF_PIN_15_STATE__);

/** GPIOG pins configuration */
#define _GPIOG_DRIVE_STRENGTH           __GPIO_PG_DRIVE_STRENGTH__
#define _GPIOG_DRIVE_STRENGTH_ALT       __GPIO_PG_DRIVE_STRENGTH_ALT__
#define _GPIOG_SLEW_RATE                __GPIO_PG_SLEW_RATE__
#define _GPIOG_SLEW_RATE_ALT            __GPIO_PG_SLEW_RATE_ALT__
#define _GPIOG_INPUT_DISABLE            __GPIO_PG_INPUT_DISABLE__
#define _GPIOG_INPUT_DISABLE_ALT        __GPIO_PG_INPUT_DISABLE_ALT__

_PIN_CONFIGURATION(GPIOG, 5,  0, __GPIO_PG_PIN_0_NAME__ , __GPIO_PG_PIN_0_MODE__ , __GPIO_PG_PIN_0_STATE__ );
_PIN_CONFIGURATION(GPIOG, 5,  1, __GPIO_PG_PIN_1_NAME__ , __GPIO_PG_PIN_1_MODE__ , __GPIO_PG_PIN_1_STATE__ );
_PIN_CONFIGURATION(GPIOG, 5,  2, __GPIO_PG_PIN_2_NAME__ , __GPIO_PG_PIN_2_MODE__ , __GPIO_PG_PIN_2_STATE__ );
_PIN_CONFIGURATION(GPIOG, 5,  3, __GPIO_PG_PIN_3_NAME__ , __GPIO_PG_PIN_3_MODE__ , __GPIO_PG_PIN_3_STATE__ );
_PIN_CONFIGURATION(GPIOG, 5,  4, __GPIO_PG_PIN_4_NAME__ , __GPIO_PG_PIN_4_MODE__ , __GPIO_PG_PIN_4_STATE__ );
_PIN_CONFIGURATION(GPIOG, 5,  5, __GPIO_PG_PIN_5_NAME__ , __GPIO_PG_PIN_5_MODE__ , __GPIO_PG_PIN_5_STATE__ );
_PIN_CONFIGURATION(GPIOG, 5,  6, __GPIO_PG_PIN_6_NAME__ , __GPIO_PG_PIN_6_MODE__ , __GPIO_PG_PIN_6_STATE__ );
_PIN_CONFIGURATION(GPIOG, 5,  7, __GPIO_PG_PIN_7_NAME__ , __GPIO_PG_PIN_7_MODE__ , __GPIO_PG_PIN_7_STATE__ );
_PIN_CONFIGURATION(GPIOG, 5,  8, __GPIO_PG_PIN_8_NAME__ , __GPIO_PG_PIN_8_MODE__ , __GPIO_PG_PIN_8_STATE__ );
_PIN_CONFIGURATION(GPIOG, 5,  9, __GPIO_PG_PIN_9_NAME__ , __GPIO_PG_PIN_9_MODE__ , __GPIO_PG_PIN_9_STATE__ );
_PIN_CONFIGURATION(GPIOG, 5, 10, __GPIO_PG_PIN_10_NAME__, __GPIO_PG_PIN_10_MODE__, __GPIO_PG_PIN_10_STATE__);
_PIN_CONFIGURATION(GPIOG, 5, 11, __GPIO_PG_PIN_11_NAME__, __GPIO_PG_PIN_11_MODE__, __GPIO_PG_PIN_11_STATE__);
_PIN_CONFIGURATION(GPIOG, 5, 12, __GPIO_PG_PIN_12_NAME__, __GPIO_PG_PIN_12_MODE__, __GPIO_PG_PIN_12_STATE__);
_PIN_CONFIGURATION(GPIOG, 5, 13, __GPIO_PG_PIN_13_NAME__, __GPIO_PG_PIN_13_MODE__, __GPIO_PG_PIN_13_STATE__);
_PIN_CONFIGURATION(GPIOG, 5, 14, __GPIO_PG_PIN_14_NAME__, __GPIO_PG_PIN_14_MODE__, __GPIO_PG_PIN_14_STATE__);
_PIN_CONFIGURATION(GPIOG, 5, 15, __GPIO_PG_PIN_15_NAME__, __GPIO_PG_PIN_15_MODE__, __GPIO_PG_PIN_15_STATE__);

/** GPIOH pins configuration */
#define _GPIOH_DRIVE_STRENGTH           __GPIO_PH_DRIVE_STRENGTH__
#define _GPIOH_DRIVE_STRENGTH_ALT       __GPIO_PH_DRIVE_STRENGTH_ALT__
#define _GPIOH_SLEW_RATE                __GPIO_PH_SLEW_RATE__
#define _GPIOH_SLEW_RATE_ALT            __GPIO_PH_SLEW_RATE_ALT__
#define _GPIOH_INPUT_DISABLE            __GPIO_PH_INPUT_DISABLE__
#define _GPIOH_INPUT_DISABLE_ALT        __GPIO_PH_INPUT_DISABLE_ALT__

_PIN_CONFIGURATION(GPIOH, 5,  0, __GPIO_PH_PIN_0_NAME__ , __GPIO_PH_PIN_0_MODE__ , __GPIO_PH_PIN_0_STATE__ );
_PIN_CONFIGURATION(GPIOH, 5,  1, __GPIO_PH_PIN_1_NAME__ , __GPIO_PH_PIN_1_MODE__ , __GPIO_PH_PIN_1_STATE__ );
_PIN_CONFIGURATION(GPIOH, 5,  2, __GPIO_PH_PIN_2_NAME__ , __GPIO_PH_PIN_2_MODE__ , __GPIO_PH_PIN_2_STATE__ );
_PIN_CONFIGURATION(GPIOH, 5,  3, __GPIO_PH_PIN_3_NAME__ , __GPIO_PH_PIN_3_MODE__ , __GPIO_PH_PIN_3_STATE__ );
_PIN_CONFIGURATION(GPIOH, 5,  4, __GPIO_PH_PIN_4_NAME__ , __GPIO_PH_PIN_4_MODE__ , __GPIO_PH_PIN_4_STATE__ );
_PIN_CONFIGURATION(GPIOH, 5,  5, __GPIO_PH_PIN_5_NAME__ , __GPIO_PH_PIN_5_MODE__ , __GPIO_PH_PIN_5_STATE__ );
_PIN_CONFIGURATION(GPIOH, 5,  6, __GPIO_PH_PIN_6_NAME__ , __GPIO_PH_PIN_6_MODE__ , __GPIO_PH_PIN_6_STATE__ );
_PIN_CONFIGURATION(GPIOH, 5,  7, __GPIO_PH_PIN_7_NAME__ , __GPIO_PH_PIN_7_MODE__ , __GPIO_PH_PIN_7_STATE__ );
_PIN_CONFIGURATION(GPIOH, 5,  8, __GPIO_PH_PIN_8_NAME__ , __GPIO_PH_PIN_8_MODE__ , __GPIO_PH_PIN_8_STATE__ );
_PIN_CONFIGURATION(GPIOH, 5,  9, __GPIO_PH_PIN_9_NAME__ , __GPIO_PH_PIN_9_MODE__ , __GPIO_PH_PIN_9_STATE__ );
_PIN_CONFIGURATION(GPIOH, 5, 10, __GPIO_PH_PIN_10_NAME__, __GPIO_PH_PIN_10_MODE__, __GPIO_PH_PIN_10_STATE__);
_PIN_CONFIGURATION(GPIOH, 5, 11, __GPIO_PH_PIN_11_NAME__, __GPIO_PH_PIN_11_MODE__, __GPIO_PH_PIN_11_STATE__);
_PIN_CONFIGURATION(GPIOH, 5, 12, __GPIO_PH_PIN_12_NAME__, __GPIO_PH_PIN_12_MODE__, __GPIO_PH_PIN_12_STATE__);
_PIN_CONFIGURATION(GPIOH, 5, 13, __GPIO_PH_PIN_13_NAME__, __GPIO_PH_PIN_13_MODE__, __GPIO_PH_PIN_13_STATE__);
_PIN_CONFIGURATION(GPIOH, 5, 14, __GPIO_PH_PIN_14_NAME__, __GPIO_PH_PIN_14_MODE__, __GPIO_PH_PIN_14_STATE__);
_PIN_CONFIGURATION(GPIOH, 5, 15, __GPIO_PH_PIN_15_NAME__, __GPIO_PH_PIN_15_MODE__, __GPIO_PH_PIN_15_STATE__);

/** GPIOI pins configuration */
#define _GPIOI_DRIVE_STRENGTH           __GPIO_PI_DRIVE_STRENGTH__
#define _GPIOI_DRIVE_STRENGTH_ALT       __GPIO_PI_DRIVE_STRENGTH_ALT__
#define _GPIOI_SLEW_RATE                __GPIO_PI_SLEW_RATE__
#define _GPIOI_SLEW_RATE_ALT            __GPIO_PI_SLEW_RATE_ALT__
#define _GPIOI_INPUT_DISABLE            __GPIO_PI_INPUT_DISABLE__
#define _GPIOI_INPUT_DISABLE_ALT        __GPIO_PI_INPUT_DISABLE_ALT__

_PIN_CONFIGURATION(GPIOI, 5,  0, __GPIO_PI_PIN_0_NAME__ , __GPIO_PI_PIN_0_MODE__ , __GPIO_PI_PIN_0_STATE__ );
_PIN_CONFIGURATION(GPIOI, 5,  1, __GPIO_PI_PIN_1_NAME__ , __GPIO_PI_PIN_1_MODE__ , __GPIO_PI_PIN_1_STATE__ );
_PIN_CONFIGURATION(GPIOI, 5,  2, __GPIO_PI_PIN_2_NAME__ , __GPIO_PI_PIN_2_MODE__ , __GPIO_PI_PIN_2_STATE__ );
_PIN_CONFIGURATION(GPIOI, 5,  3, __GPIO_PI_PIN_3_NAME__ , __GPIO_PI_PIN_3_MODE__ , __GPIO_PI_PIN_3_STATE__ );
_PIN_CONFIGURATION(GPIOI, 5,  4, __GPIO_PI_PIN_4_NAME__ , __GPIO_PI_PIN_4_MODE__ , __GPIO_PI_PIN_4_STATE__ );
_PIN_CONFIGURATION(GPIOI, 5,  5, __GPIO_PI_PIN_5_NAME__ , __GPIO_PI_PIN_5_MODE__ , __GPIO_PI_PIN_5_STATE__ );
_PIN_CONFIGURATION(GPIOI, 5,  6, __GPIO_PI_PIN_6_NAME__ , __GPIO_PI_PIN_6_MODE__ , __GPIO_PI_PIN_6_STATE__ );
_PIN_CONFIGURATION(GPIOI, 5,  7, __GPIO_PI_PIN_7_NAME__ , __GPIO_PI_PIN_7_MODE__ , __GPIO_PI_PIN_7_STATE__ );
_PIN_CONFIGURATION(GPIOI, 5,  8, __GPIO_PI_PIN_8_NAME__ , __GPIO_PI_PIN_8_MODE__ , __GPIO_PI_PIN_8_STATE__ );
_PIN_CONFIGURATION(GPIOI, 5,  9, __GPIO_PI_PIN_9_NAME__ , __GPIO_PI_PIN_9_MODE__ , __GPIO_PI_PIN_9_STATE__ );
_PIN_CONFIGURATION(GPIOI, 5, 10, __GPIO_PI_PIN_10_NAME__, __GPIO_PI_PIN_10_MODE__, __GPIO_PI_PIN_10_STATE__);
_PIN_CONFIGURATION(GPIOI, 5, 11, __GPIO_PI_PIN_11_NAME__, __GPIO_PI_PIN_11_MODE__, __GPIO_PI_PIN_11_STATE__);
_PIN_CONFIGURATION(GPIOI, 5, 12, __GPIO_PI_PIN_12_NAME__, __GPIO_PI_PIN_12_MODE__, __GPIO_PI_PIN_12_STATE__);
_PIN_CONFIGURATION(GPIOI, 5, 13, __GPIO_PI_PIN_13_NAME__, __GPIO_PI_PIN_13_MODE__, __GPIO_PI_PIN_13_STATE__);
_PIN_CONFIGURATION(GPIOI, 5, 14, __GPIO_PI_PIN_14_NAME__, __GPIO_PI_PIN_14_MODE__, __GPIO_PI_PIN_14_STATE__);
_PIN_CONFIGURATION(GPIOI, 5, 15, __GPIO_PI_PIN_15_NAME__, __GPIO_PI_PIN_15_MODE__, __GPIO_PI_PIN_15_STATE__);

/** GPIOJ pins configuration */
#define _GPIOJ_DRIVE_STRENGTH           __GPIO_PJ_DRIVE_STRENGTH__
#define _GPIOJ_DRIVE_STRENGTH_ALT       __GPIO_PJ_DRIVE_STRENGTH_ALT__
#define _GPIOJ_SLEW_RATE                __GPIO_PJ_SLEW_RATE__
#define _GPIOJ_SLEW_RATE_ALT            __GPIO_PJ_SLEW_RATE_ALT__
#define _GPIOJ_INPUT_DISABLE            __GPIO_PJ_INPUT_DISABLE__
#define _GPIOJ_INPUT_DISABLE_ALT        __GPIO_PJ_INPUT_DISABLE_ALT__

_PIN_CONFIGURATION(GPIOJ, 5,  0, __GPIO_PJ_PIN_0_NAME__ , __GPIO_PJ_PIN_0_MODE__ , __GPIO_PJ_PIN_0_STATE__ );
_PIN_CONFIGURATION(GPIOJ, 5,  1, __GPIO_PJ_PIN_1_NAME__ , __GPIO_PJ_PIN_1_MODE__ , __GPIO_PJ_PIN_1_STATE__ );
_PIN_CONFIGURATION(GPIOJ, 5,  2, __GPIO_PJ_PIN_2_NAME__ , __GPIO_PJ_PIN_2_MODE__ , __GPIO_PJ_PIN_2_STATE__ );
_PIN_CONFIGURATION(GPIOJ, 5,  3, __GPIO_PJ_PIN_3_NAME__ , __GPIO_PJ_PIN_3_MODE__ , __GPIO_PJ_PIN_3_STATE__ );
_PIN_CONFIGURATION(GPIOJ, 5,  4, __GPIO_PJ_PIN_4_NAME__ , __GPIO_PJ_PIN_4_MODE__ , __GPIO_PJ_PIN_4_STATE__ );
_PIN_CONFIGURATION(GPIOJ, 5,  5, __GPIO_PJ_PIN_5_NAME__ , __GPIO_PJ_PIN_5_MODE__ , __GPIO_PJ_PIN_5_STATE__ );
_PIN_CONFIGURATION(GPIOJ, 5,  6, __GPIO_PJ_PIN_6_NAME__ , __GPIO_PJ_PIN_6_MODE__ , __GPIO_PJ_PIN_6_STATE__ );
_PIN_CONFIGURATION(GPIOJ, 5,  7, __GPIO_PJ_PIN_7_NAME__ , __GPIO_PJ_PIN_7_MODE__ , __GPIO_PJ_PIN_7_STATE__ );
_PIN_CONFIGURATION(GPIOJ, 5,  8, __GPIO_PJ_PIN_8_NAME__ , __GPIO_PJ_PIN_8_MODE__ , __GPIO_PJ_PIN_8_STATE__ );
_PIN_CONFIGURATION(GPIOJ, 5,  9, __GPIO_PJ_PIN_9_NAME__ , __GPIO_PJ_PIN_9_MODE__ , __GPIO_PJ_PIN_9_STATE__ );
_PIN_CONFIGURATION(GPIOJ, 5, 10, __GPIO_PJ_PIN_10_NAME__, __GPIO_PJ_PIN_10_MODE__, __GPIO_PJ_PIN_10_STATE__);
_PIN_CONFIGURATION(GPIOJ, 5, 11, __GPIO_PJ_PIN_11_NAME__, __GPIO_PJ_PIN_11_MODE__, __GPIO_PJ_PIN_11_STATE__);
_PIN_CONFIGURATION(GPIOJ, 5, 12, __GPIO_PJ_PIN_12_NAME__, __GPIO_PJ_PIN_12_MODE__, __GPIO_PJ_PIN_12_STATE__);
_PIN_CONFIGURATION(GPIOJ, 5, 13, __GPIO_PJ_PIN_13_NAME__, __GPIO_PJ_PIN_13_MODE__, __GPIO_PJ_PIN_13_STATE__);
_PIN_CONFIGURATION(GPIOJ, 5, 14, __GPIO_PJ_PIN_14_NAME__, __GPIO_PJ_PIN_14_MODE__, __GPIO_PJ_PIN_14_STATE__);
_PIN_CONFIGURATION(GPIOJ, 5, 15, __GPIO_PJ_PIN_15_NAME__, __GPIO_PJ_PIN_15_MODE__, __GPIO_PJ_PIN_15_STATE__);

/** GPIOK pins configuration */
#define _GPIOK_DRIVE_STRENGTH           __GPIO_PK_DRIVE_STRENGTH__
#define _GPIOK_DRIVE_STRENGTH_ALT       __GPIO_PK_DRIVE_STRENGTH_ALT__
#define _GPIOK_SLEW_RATE                __GPIO_PK_SLEW_RATE__
#define _GPIOK_SLEW_RATE_ALT            __GPIO_PK_SLEW_RATE_ALT__
#define _GPIOK_INPUT_DISABLE            __GPIO_PK_INPUT_DISABLE__
#define _GPIOK_INPUT_DISABLE_ALT        __GPIO_PK_INPUT_DISABLE_ALT__

_PIN_CONFIGURATION(GPIOK, 5,  0, __GPIO_PK_PIN_0_NAME__ , __GPIO_PK_PIN_0_MODE__ , __GPIO_PK_PIN_0_STATE__ );
_PIN_CONFIGURATION(GPIOK, 5,  1, __GPIO_PK_PIN_1_NAME__ , __GPIO_PK_PIN_1_MODE__ , __GPIO_PK_PIN_1_STATE__ );
_PIN_CONFIGURATION(GPIOK, 5,  2, __GPIO_PK_PIN_2_NAME__ , __GPIO_PK_PIN_2_MODE__ , __GPIO_PK_PIN_2_STATE__ );
_PIN_CONFIGURATION(GPIOK, 5,  3, __GPIO_PK_PIN_3_NAME__ , __GPIO_PK_PIN_3_MODE__ , __GPIO_PK_PIN_3_STATE__ );
_PIN_CONFIGURATION(GPIOK, 5,  4, __GPIO_PK_PIN_4_NAME__ , __GPIO_PK_PIN_4_MODE__ , __GPIO_PK_PIN_4_STATE__ );
_PIN_CONFIGURATION(GPIOK, 5,  5, __GPIO_PK_PIN_5_NAME__ , __GPIO_PK_PIN_5_MODE__ , __GPIO_PK_PIN_5_STATE__ );
_PIN_CONFIGURATION(GPIOK, 5,  6, __GPIO_PK_PIN_6_NAME__ , __GPIO_PK_PIN_6_MODE__ , __GPIO_PK_PIN_6_STATE__ );
_PIN_CONFIGURATION(GPIOK, 5,  7, __GPIO_PK_PIN_7_NAME__ , __GPIO_PK_PIN_7_MODE__ , __GPIO_PK_PIN_7_STATE__ );
_PIN_CONFIGURATION(GPIOK, 5,  8, __GPIO_PK_PIN_8_NAME__ , __GPIO_PK_PIN_8_MODE__ , __GPIO_PK_PIN_8_STATE__ );
_PIN_CONFIGURATION(GPIOK, 5,  9, __GPIO_PK_PIN_9_NAME__ , __GPIO_PK_PIN_9_MODE__ , __GPIO_PK_PIN_9_STATE__ );
_PIN_CONFIGURATION(GPIOK, 5, 10, __GPIO_PK_PIN_10_NAME__, __GPIO_PK_PIN_10_MODE__, __GPIO_PK_PIN_10_STATE__);
_PIN_CONFIGURATION(GPIOK, 5, 11, __GPIO_PK_PIN_11_NAME__, __GPIO_PK_PIN_11_MODE__, __GPIO_PK_PIN_11_STATE__);
_PIN_CONFIGURATION(GPIOK, 5, 12, __GPIO_PK_PIN_12_NAME__, __GPIO_PK_PIN_12_MODE__, __GPIO_PK_PIN_12_STATE__);
_PIN_CONFIGURATION(GPIOK, 5, 13, __GPIO_PK_PIN_13_NAME__, __GPIO_PK_PIN_13_MODE__, __GPIO_PK_PIN_13_STATE__);
_PIN_CONFIGURATION(GPIOK, 5, 14, __GPIO_PK_PIN_14_NAME__, __GPIO_PK_PIN_14_MODE__, __GPIO_PK_PIN_14_STATE__);
_PIN_CONFIGURATION(GPIOK, 5, 15, __GPIO_PK_PIN_15_NAME__, __GPIO_PK_PIN_15_MODE__, __GPIO_PK_PIN_15_STATE__);

/*==============================================================================
  Exported types, enums definitions
==============================================================================*/

/*==============================================================================
  Exported object declarations
==============================================================================*/

/*==============================================================================
  Exported function prototypes
==============================================================================*/

#ifdef __cplusplus
}
#endif

#endif /* _GPIO_CFG_H_ */
/*==============================================================================
  End of file
==============================================================================*/
